@@ -63,12 +63,13 @@ def remote_app_deploy(app_dir: str, login_info: str, local_source: str, remote_d
         print('App deployed to', remote_dest_dir)
         utils.ssh_run_commands(login_info, [
             f'echo {remote_dest_dir} > {app_dir}/.compss',
+            f'mkdir -p {os.path.dirname(remote_dest_dir)}',
             f'ln -s {app_dir} {remote_dest_dir}'
         ])
 
 def remote_app_remove(login_info: str, app_dir: str):
     utils.ssh_run_commands(login_info, [
-            f'cat {app_dir}/.compss | xargs rm',
+            f'cat {app_dir}/.compss | xargs rm -rf',
             f'rm -rf {app_dir}'
         ])
 
